function Get-ROSSTransaction {
<#
    .SYNOPSIS
        Returns a RES ONE Service transaction reference.
    .EXAMPLE
        Get-ROSSTransaction

        Returns the first 50 transactions.
    .EXAMPLE
        Get-ROSSTransaction -ServiceId 'a13003e7-3c51-4c22-9c9e-0a8210813ed1'

        Returns the first 50 transactions for a service.
    .EXAMPLE
        Get-ROSSTransaction -ServiceId 'a13003e7-3c51-4c22-9c9e-0a8210813ed1' -Count

        Returns the number of transactions associated with a service.
    .EXAMPLE
        Get-ROSSTransaction -ServiceId 'a13003e7-3c51-4c22-9c9e-0a8210813ed1' -State Failed

        Returns the first 50 failed service delivery transactions for a service.
    .EXAMPLE
        Get-ROSSTransaction -PersonId 'b6af5c3a-601c-47a3-a551-075df7f96e33'

        Returns the first 50 transactions for a person.
    .EXAMPLE
        Get-ROSSTransaction -PersonId 'b6af5c3a-601c-47a3-a551-075df7f96e33' -Direction Deliver

        Returns the first 50 service delivery transactions for a person.
    .EXAMPLE
        Get-ROSSTransaction -PersonId 'b6af5c3a-601c-47a3-a551-075df7f96e33' -Count

        Returns the number of transactions associated with a person.
    .EXAMPLE
        Get-ROSSTransaction -Id 'fd86f088-5105-4aab-98ed-18e56756aef7'

        Returns the a specific RES ONE Service transaction by its Id.
    .EXAMPLE
        Get-ROSSOrganization -Path 'Departments\Sales' | Get-ROSSPerson | Get-ROSSTransaction

        Returns all transactions for people classified in the 'Departments\Sales' organizational context
#>
    [CmdletBinding(DefaultParameterSetName = 'Default')]
    [OutputType([System.Management.Automation.PSCustomObject], ParameterSetName = 'Default')]
    [OutputType([System.Management.Automation.PSCustomObject], ParameterSetName = 'Transaction')]
    [OutputType([System.Int32], ParameterSetName = 'Count')]
    param (
        # RES ONE Service Store session connection
        [Parameter(ValueFromPipelineByPropertyName)]
        [System.Collections.Hashtable] $Session = $script:_RESONEServiceStoreSession,

        # Specifies returning transactions related to a specific RES ONE Service Store service Id.
        [Parameter(ValueFromPipelineByPropertyName, ParameterSetName = 'Default')]
        [Parameter(ValueFromPipelineByPropertyName, ParameterSetName = 'Count')]
        [System.String] $ServiceId,

        # Specifies returning transactions related to a specific RES ONE Service Store person Id.
        [Parameter(ValueFromPipelineByPropertyName, ParameterSetName = 'Default')]
        [Parameter(ValueFromPipelineByPropertyName, ParameterSetName = 'Count')]
        [System.String] $PersonId,

        # Specifies the RES ONE Service Store transaction Id to return.
        [Parameter(Mandatory, ValueFromPipelineByPropertyName, ParameterSetName = 'Transaction')]
        [System.String] $Id,

        # Search transactions starting on or before the specified date/time.
        [Parameter(ValueFromPipelineByPropertyName, ParameterSetName = 'Default')]
        [Parameter(ValueFromPipelineByPropertyName, ParameterSetName = 'Count')]
        [System.DateTime] $StartDate,

        # Search transactions ending on or before the specified date/time.
        [Parameter(ValueFromPipelineByPropertyName, ParameterSetName = 'Default')]
        [Parameter(ValueFromPipelineByPropertyName, ParameterSetName = 'Count')]
        [System.DateTime] $EndDate,

        # Transaction type. If not specified, both delivery and return transactions are returned.
        [Parameter(ValueFromPipelineByPropertyName, ParameterSetName = 'Default')]
        [Parameter(ValueFromPipelineByPropertyName, ParameterSetName = 'Count')]
        [ValidateSet('Deliver','Return')]
        [System.String] $Direction,

        # Transaction state. If not specified, both delivery and return transactions are returned.
        [Parameter(ValueFromPipelineByPropertyName, ParameterSetName = 'Default')]
        [Parameter(ValueFromPipelineByPropertyName, ParameterSetName = 'Count')]
        [ValidateSet('Completed','Pending','Failed','Aborted','OnHold')]
        [System.String] $State,

        # Search page number to return. By default, search results are paginated and only the first page results are returned.
        [Parameter(ValueFromPipelineByPropertyName, ParameterSetName = 'Default')]
        [ValidateRange(1,65535)]
        [System.Int32] $Page = 1,

        # Specifies the number of results per page. By default, search results are paginated and only the first page results are returned.
        [Parameter(ValueFromPipelineByPropertyName, ParameterSetName = 'Default')]
        [ValidateRange(1,65535)]
        [System.Int32] $PageSize = 50,

        # Specifies returning only the number of available transactions matching the search criteria.
        [Parameter(Mandatory, ValueFromPipelineByPropertyName, ParameterSetName = 'Count')]
        [System.Management.Automation.SwitchParameter] $Count
    )
    begin {

        Assert-ROSSSession -Session $Session;

        if (($PSBoundParameters.ContainsKey('StartDate')) -and
            ($PSBoundParameters.ContainsKey('EndDate'))) {

            if ($EndDate -lt $StartDate) {
                throw ($localizedData.StartDateAfterEndDateError);
            }
        }
    }
    process {

        Write-Verbose $PSCmdlet.ParameterSetName

        $typeName = 'VirtualEngine.ROSS.Transaction';
        $uri = Get-ROSSResourceUri -Session $Session -Transaction -Search;

        $requestBody = @{
            filters = @{};
            orderBy = @('StartDate');
        }

        if ($PSCmdlet.ParameterSetName -eq 'Default') {

            $requestBody['pageNumber'] = $Page;
            $requestBody['pageSize'] = $PageSize;
        }

        if ($PSBoundParameters.ContainsKey('PersonId')) {

            $requestBody.Filters['PersonId'] = $PersonId;
        }
        if ($PSBoundParameters.ContainsKey('PersonName')) {

            $requestBody.Filters['PersonName'] = $PersonName;
        }
        if ($PSBoundParameters.ContainsKey('ServiceId')) {

            $requestBody.Filters['ServiceId'] = $ServiceId;
        }
        if ($PSBoundParameters.ContainsKey('Direction')) {

            $requestBody.Filters['Direction'] = if ($Direction -eq 'Deliver') { 'Provision' } else { 'Deprovision' };
        }
        if ($PSBoundParameters.ContainsKey('State')) {

            $requestBody.Filters['State'] = $State;
        }
        if ($PSBoundParameters.ContainsKey('StartDate')) {

            $requestBody.Filters['StartDate'] = $StartDate.ToUniversalTime().ToString('yyyy-MM-ddTHH:mm:ssZ');
        }
        if ($PSBoundParameters.ContainsKey('EndDate')) {

            $requestBody.Filters['EndDate'] = $EndDate.ToUniversalTime().ToString('yyyy-MM-ddTHH:mm:ssZ');
        }

        $invokeROSSRestMethodParams = @{
            Session = $Session;
            Uri = $uri;
            Method = 'Post';
            Body = $requestBody;
        }

        if ($PSCmdlet.ParameterSetName -eq 'Count') {

            Write-Output -InputObject (Invoke-ROSSRestMethod @invokeROSSRestMethodParams).TotalCount;
        }
        else {

            try {

                Invoke-ROSSRestMethod @invokeROSSRestMethodParams -ExpandProperty 'Result' |
                    ForEach-Object {

                        $PSItem.PSObject.TypeNames.Insert(0, $TypeName);

                        $startDateTime = $PSItem.UtcStartDate -as [System.DateTime];
                        $endDateTime = $PSItem.UtcEndDate -as [System.DateTime];
                        $deliveryAction = if ($PSItem.Direction -eq 'Provision') { 'Deliver' } else { 'Return ' }
                        Add-Member -InputObject $PSItem -MemberType NoteProperty -Name Action -Value $deliveryAction;
                        Add-Member -InputObject $PSItem -MemberType NoteProperty -Name StartDate -Value $startDateTime;
                        Add-Member -InputObject $PSItem -MemberType NoteProperty -Name EndDate -Value $endDateTime;

                        Write-Output -InputObject $PSItem;
                    }
            }
            catch {

                throw;
            }
        }

    } #end process
} #end function

# SIG # Begin signature block
# MIIX1gYJKoZIhvcNAQcCoIIXxzCCF8MCAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQURiU7Rk1TP5zbglHPlXCBD5LK
# ImygghMJMIID7jCCA1egAwIBAgIQfpPr+3zGTlnqS5p31Ab8OzANBgkqhkiG9w0B
# AQUFADCBizELMAkGA1UEBhMCWkExFTATBgNVBAgTDFdlc3Rlcm4gQ2FwZTEUMBIG
# A1UEBxMLRHVyYmFudmlsbGUxDzANBgNVBAoTBlRoYXd0ZTEdMBsGA1UECxMUVGhh
# d3RlIENlcnRpZmljYXRpb24xHzAdBgNVBAMTFlRoYXd0ZSBUaW1lc3RhbXBpbmcg
# Q0EwHhcNMTIxMjIxMDAwMDAwWhcNMjAxMjMwMjM1OTU5WjBeMQswCQYDVQQGEwJV
# UzEdMBsGA1UEChMUU3ltYW50ZWMgQ29ycG9yYXRpb24xMDAuBgNVBAMTJ1N5bWFu
# dGVjIFRpbWUgU3RhbXBpbmcgU2VydmljZXMgQ0EgLSBHMjCCASIwDQYJKoZIhvcN
# AQEBBQADggEPADCCAQoCggEBALGss0lUS5ccEgrYJXmRIlcqb9y4JsRDc2vCvy5Q
# WvsUwnaOQwElQ7Sh4kX06Ld7w3TMIte0lAAC903tv7S3RCRrzV9FO9FEzkMScxeC
# i2m0K8uZHqxyGyZNcR+xMd37UWECU6aq9UksBXhFpS+JzueZ5/6M4lc/PcaS3Er4
# ezPkeQr78HWIQZz/xQNRmarXbJ+TaYdlKYOFwmAUxMjJOxTawIHwHw103pIiq8r3
# +3R8J+b3Sht/p8OeLa6K6qbmqicWfWH3mHERvOJQoUvlXfrlDqcsn6plINPYlujI
# fKVOSET/GeJEB5IL12iEgF1qeGRFzWBGflTBE3zFefHJwXECAwEAAaOB+jCB9zAd
# BgNVHQ4EFgQUX5r1blzMzHSa1N197z/b7EyALt0wMgYIKwYBBQUHAQEEJjAkMCIG
# CCsGAQUFBzABhhZodHRwOi8vb2NzcC50aGF3dGUuY29tMBIGA1UdEwEB/wQIMAYB
# Af8CAQAwPwYDVR0fBDgwNjA0oDKgMIYuaHR0cDovL2NybC50aGF3dGUuY29tL1Ro
# YXd0ZVRpbWVzdGFtcGluZ0NBLmNybDATBgNVHSUEDDAKBggrBgEFBQcDCDAOBgNV
# HQ8BAf8EBAMCAQYwKAYDVR0RBCEwH6QdMBsxGTAXBgNVBAMTEFRpbWVTdGFtcC0y
# MDQ4LTEwDQYJKoZIhvcNAQEFBQADgYEAAwmbj3nvf1kwqu9otfrjCR27T4IGXTdf
# plKfFo3qHJIJRG71betYfDDo+WmNI3MLEm9Hqa45EfgqsZuwGsOO61mWAK3ODE2y
# 0DGmCFwqevzieh1XTKhlGOl5QGIllm7HxzdqgyEIjkHq3dlXPx13SYcqFgZepjhq
# IhKjURmDfrYwggSjMIIDi6ADAgECAhAOz/Q4yP6/NW4E2GqYGxpQMA0GCSqGSIb3
# DQEBBQUAMF4xCzAJBgNVBAYTAlVTMR0wGwYDVQQKExRTeW1hbnRlYyBDb3Jwb3Jh
# dGlvbjEwMC4GA1UEAxMnU3ltYW50ZWMgVGltZSBTdGFtcGluZyBTZXJ2aWNlcyBD
# QSAtIEcyMB4XDTEyMTAxODAwMDAwMFoXDTIwMTIyOTIzNTk1OVowYjELMAkGA1UE
# BhMCVVMxHTAbBgNVBAoTFFN5bWFudGVjIENvcnBvcmF0aW9uMTQwMgYDVQQDEytT
# eW1hbnRlYyBUaW1lIFN0YW1waW5nIFNlcnZpY2VzIFNpZ25lciAtIEc0MIIBIjAN
# BgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAomMLOUS4uyOnREm7Dv+h8GEKU5Ow
# mNutLA9KxW7/hjxTVQ8VzgQ/K/2plpbZvmF5C1vJTIZ25eBDSyKV7sIrQ8Gf2Gi0
# jkBP7oU4uRHFI/JkWPAVMm9OV6GuiKQC1yoezUvh3WPVF4kyW7BemVqonShQDhfu
# ltthO0VRHc8SVguSR/yrrvZmPUescHLnkudfzRC5xINklBm9JYDh6NIipdC6Anqh
# d5NbZcPuF3S8QYYq3AhMjJKMkS2ed0QfaNaodHfbDlsyi1aLM73ZY8hJnTrFxeoz
# C9Lxoxv0i77Zs1eLO94Ep3oisiSuLsdwxb5OgyYI+wu9qU+ZCOEQKHKqzQIDAQAB
# o4IBVzCCAVMwDAYDVR0TAQH/BAIwADAWBgNVHSUBAf8EDDAKBggrBgEFBQcDCDAO
# BgNVHQ8BAf8EBAMCB4AwcwYIKwYBBQUHAQEEZzBlMCoGCCsGAQUFBzABhh5odHRw
# Oi8vdHMtb2NzcC53cy5zeW1hbnRlYy5jb20wNwYIKwYBBQUHMAKGK2h0dHA6Ly90
# cy1haWEud3Muc3ltYW50ZWMuY29tL3Rzcy1jYS1nMi5jZXIwPAYDVR0fBDUwMzAx
# oC+gLYYraHR0cDovL3RzLWNybC53cy5zeW1hbnRlYy5jb20vdHNzLWNhLWcyLmNy
# bDAoBgNVHREEITAfpB0wGzEZMBcGA1UEAxMQVGltZVN0YW1wLTIwNDgtMjAdBgNV
# HQ4EFgQURsZpow5KFB7VTNpSYxc/Xja8DeYwHwYDVR0jBBgwFoAUX5r1blzMzHSa
# 1N197z/b7EyALt0wDQYJKoZIhvcNAQEFBQADggEBAHg7tJEqAEzwj2IwN3ijhCcH
# bxiy3iXcoNSUA6qGTiWfmkADHN3O43nLIWgG2rYytG2/9CwmYzPkSWRtDebDZw73
# BaQ1bHyJFsbpst+y6d0gxnEPzZV03LZc3r03H0N45ni1zSgEIKOq8UvEiCmRDoDR
# EfzdXHZuT14ORUZBbg2w6jiasTraCXEQ/Bx5tIB7rGn0/Zy2DBYr8X9bCT2bW+IW
# yhOBbQAuOA2oKY8s4bL0WqkBrxWcLC9JG9siu8P+eJRRw4axgohd8D20UaF5Mysu
# e7ncIAkTcetqGVvP6KUwVyyJST+5z3/Jvz4iaGNTmr1pdKzFHTx/kuDDvBzYBHUw
# ggUwMIIEGKADAgECAhAECRgbX9W7ZnVTQ7VvlVAIMA0GCSqGSIb3DQEBCwUAMGUx
# CzAJBgNVBAYTAlVTMRUwEwYDVQQKEwxEaWdpQ2VydCBJbmMxGTAXBgNVBAsTEHd3
# dy5kaWdpY2VydC5jb20xJDAiBgNVBAMTG0RpZ2lDZXJ0IEFzc3VyZWQgSUQgUm9v
# dCBDQTAeFw0xMzEwMjIxMjAwMDBaFw0yODEwMjIxMjAwMDBaMHIxCzAJBgNVBAYT
# AlVTMRUwEwYDVQQKEwxEaWdpQ2VydCBJbmMxGTAXBgNVBAsTEHd3dy5kaWdpY2Vy
# dC5jb20xMTAvBgNVBAMTKERpZ2lDZXJ0IFNIQTIgQXNzdXJlZCBJRCBDb2RlIFNp
# Z25pbmcgQ0EwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQD407Mcfw4R
# r2d3B9MLMUkZz9D7RZmxOttE9X/lqJ3bMtdx6nadBS63j/qSQ8Cl+YnUNxnXtqrw
# nIal2CWsDnkoOn7p0WfTxvspJ8fTeyOU5JEjlpB3gvmhhCNmElQzUHSxKCa7JGnC
# wlLyFGeKiUXULaGj6YgsIJWuHEqHCN8M9eJNYBi+qsSyrnAxZjNxPqxwoqvOf+l8
# y5Kh5TsxHM/q8grkV7tKtel05iv+bMt+dDk2DZDv5LVOpKnqagqrhPOsZ061xPeM
# 0SAlI+sIZD5SlsHyDxL0xY4PwaLoLFH3c7y9hbFig3NBggfkOItqcyDQD2RzPJ6f
# pjOp/RnfJZPRAgMBAAGjggHNMIIByTASBgNVHRMBAf8ECDAGAQH/AgEAMA4GA1Ud
# DwEB/wQEAwIBhjATBgNVHSUEDDAKBggrBgEFBQcDAzB5BggrBgEFBQcBAQRtMGsw
# JAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLmRpZ2ljZXJ0LmNvbTBDBggrBgEFBQcw
# AoY3aHR0cDovL2NhY2VydHMuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0QXNzdXJlZElE
# Um9vdENBLmNydDCBgQYDVR0fBHoweDA6oDigNoY0aHR0cDovL2NybDQuZGlnaWNl
# cnQuY29tL0RpZ2lDZXJ0QXNzdXJlZElEUm9vdENBLmNybDA6oDigNoY0aHR0cDov
# L2NybDMuZGlnaWNlcnQuY29tL0RpZ2lDZXJ0QXNzdXJlZElEUm9vdENBLmNybDBP
# BgNVHSAESDBGMDgGCmCGSAGG/WwAAgQwKjAoBggrBgEFBQcCARYcaHR0cHM6Ly93
# d3cuZGlnaWNlcnQuY29tL0NQUzAKBghghkgBhv1sAzAdBgNVHQ4EFgQUWsS5eyoK
# o6XqcQPAYPkt9mV1DlgwHwYDVR0jBBgwFoAUReuir/SSy4IxLVGLp6chnfNtyA8w
# DQYJKoZIhvcNAQELBQADggEBAD7sDVoks/Mi0RXILHwlKXaoHV0cLToaxO8wYdd+
# C2D9wz0PxK+L/e8q3yBVN7Dh9tGSdQ9RtG6ljlriXiSBThCk7j9xjmMOE0ut119E
# efM2FAaK95xGTlz/kLEbBw6RFfu6r7VRwo0kriTGxycqoSkoGjpxKAI8LpGjwCUR
# 4pwUR6F6aGivm6dcIFzZcbEMj7uo+MUSaJ/PQMtARKUT8OZkDCUIQjKyNookAv4v
# cn4c10lFluhZHen6dGRrsutmQ9qzsIzV6Q3d9gEgzpkxYz0IGhizgZtPxpMQBvwH
# gfqL2vmCSfdibqFT+hKUGIUukpHqaGxEMrJmoecYpJpkUe8wggU4MIIEIKADAgEC
# AhAPxQCJrE9ObGzkCRS7EwyyMA0GCSqGSIb3DQEBCwUAMHIxCzAJBgNVBAYTAlVT
# MRUwEwYDVQQKEwxEaWdpQ2VydCBJbmMxGTAXBgNVBAsTEHd3dy5kaWdpY2VydC5j
# b20xMTAvBgNVBAMTKERpZ2lDZXJ0IFNIQTIgQXNzdXJlZCBJRCBDb2RlIFNpZ25p
# bmcgQ0EwHhcNMTcwNTI2MDAwMDAwWhcNMTkwOTI3MTIwMDAwWjB1MQswCQYDVQQG
# EwJHQjETMBEGA1UECBMKR2Fyc2luZ3RvbjEPMA0GA1UEBxMGT3hmb3JkMR8wHQYD
# VQQKExZWaXJ0dWFsIEVuZ2luZSBMaW1pdGVkMR8wHQYDVQQDExZWaXJ0dWFsIEVu
# Z2luZSBMaW1pdGVkMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAnB1O
# DV2jw/aMIUWnD9f9RCbAoiJ8LQcznYo42P22YEi6g7QY+kKmAzGgEhbsE4UVuGWS
# el4y6FxGWq51SK5P/gqgZgzyP8FkIUzLxsCrtx9OBnsPPeL+/An5CpcsKsl2lCSz
# NMwcz16hjcE0vCLio1NOcwvfO65qdNT2gRIEnIYhRX88dG3V30BH2aKWG5X9t1IW
# RmozjZ8I7iLEoWFJWQSuICSGyvyiPqnXF3nxdroE8O4fc1U90x5qefX0RlwKeq47
# UFuI0Y/59pB3/jss5BYvAXp3g+6EKlDwgW1a/MLVsLQbdzlALFUv5YxEqkXA8IEM
# xpwgBjm117SmyZ98QQIDAQABo4IBxTCCAcEwHwYDVR0jBBgwFoAUWsS5eyoKo6Xq
# cQPAYPkt9mV1DlgwHQYDVR0OBBYEFL5NkOqMm0S8AyuXI1EZIdoK9DD/MA4GA1Ud
# DwEB/wQEAwIHgDATBgNVHSUEDDAKBggrBgEFBQcDAzB3BgNVHR8EcDBuMDWgM6Ax
# hi9odHRwOi8vY3JsMy5kaWdpY2VydC5jb20vc2hhMi1hc3N1cmVkLWNzLWcxLmNy
# bDA1oDOgMYYvaHR0cDovL2NybDQuZGlnaWNlcnQuY29tL3NoYTItYXNzdXJlZC1j
# cy1nMS5jcmwwTAYDVR0gBEUwQzA3BglghkgBhv1sAwEwKjAoBggrBgEFBQcCARYc
# aHR0cHM6Ly93d3cuZGlnaWNlcnQuY29tL0NQUzAIBgZngQwBBAEwgYQGCCsGAQUF
# BwEBBHgwdjAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AuZGlnaWNlcnQuY29tME4G
# CCsGAQUFBzAChkJodHRwOi8vY2FjZXJ0cy5kaWdpY2VydC5jb20vRGlnaUNlcnRT
# SEEyQXNzdXJlZElEQ29kZVNpZ25pbmdDQS5jcnQwDAYDVR0TAQH/BAIwADANBgkq
# hkiG9w0BAQsFAAOCAQEAQC8qzSz1bIoEqbjDx3VtYDjtUjuFEVDFYi9+vREl6jM+
# iqOiNiwCXUkbxGTuDrWW9I1YOn8a7SCCYapZ+T0G3RMa+rQHXFYKbYTmXC3C41Cd
# MQzZn4wTuGRNQLTgNSuclwMnNmFVe7K5S/0Dv+GaLSKuRLAxpcPxeTtmRZIIBXF7
# wwRS0+V28jB9VyeSOdqsPIFYf5GSfu7KcIhmNQ/DUroulaS5JIrPUhwkf1LZMm0B
# /0adpaPbFy95M1emij96rrgy2hX8N/FrWBh13/81V6NO3b8mhCfjqb632dG4EUTi
# FXDvqP2hpWw0nO/pFZsMsEK88eiV93XDDEG/MjAApzGCBDcwggQzAgEBMIGGMHIx
# CzAJBgNVBAYTAlVTMRUwEwYDVQQKEwxEaWdpQ2VydCBJbmMxGTAXBgNVBAsTEHd3
# dy5kaWdpY2VydC5jb20xMTAvBgNVBAMTKERpZ2lDZXJ0IFNIQTIgQXNzdXJlZCBJ
# RCBDb2RlIFNpZ25pbmcgQ0ECEA/FAImsT05sbOQJFLsTDLIwCQYFKw4DAhoFAKB4
# MBgGCisGAQQBgjcCAQwxCjAIoAKAAKECgAAwGQYJKoZIhvcNAQkDMQwGCisGAQQB
# gjcCAQQwHAYKKwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUwIwYJKoZIhvcNAQkE
# MRYEFLOO6RO2QxeKw6sJ4Q3EmprPEhprMA0GCSqGSIb3DQEBAQUABIIBADVlUyD6
# 7ukifYr5DFS3m63PNDWQkauxubZMaBh30zmh6oN475Jpf/V51rF7+r6iARfFc8wy
# gbcfD5fNrZ+VNmOG4eukYkKLXIGXuZtozkfRphy9CSodISg078iLJRwjhOnkeqnj
# MAt8Qu9EtkH1fYRCV34jPbwj7FjPualoXDkhN+neu5I57r7s1pBRHV3afsI5Uf6I
# ilyjbMe47to0ccOEJncjtzOpF5Y8HLfqeL1chMSmmlK3vyvNUddNJHeB+Rn2RvIe
# RHlfV8C3tz/cBz4/CeYg420V9rPUJeVlK5LsOQ/ODK867NzNZ22kx43U4+ZNIxiJ
# B85iGfMxPc2WMQahggILMIICBwYJKoZIhvcNAQkGMYIB+DCCAfQCAQEwcjBeMQsw
# CQYDVQQGEwJVUzEdMBsGA1UEChMUU3ltYW50ZWMgQ29ycG9yYXRpb24xMDAuBgNV
# BAMTJ1N5bWFudGVjIFRpbWUgU3RhbXBpbmcgU2VydmljZXMgQ0EgLSBHMgIQDs/0
# OMj+vzVuBNhqmBsaUDAJBgUrDgMCGgUAoF0wGAYJKoZIhvcNAQkDMQsGCSqGSIb3
# DQEHATAcBgkqhkiG9w0BCQUxDxcNMTcxMTA4MTEzMzQ3WjAjBgkqhkiG9w0BCQQx
# FgQU7ejtEMS3JkohD8Fu4aI02Mb8GvwwDQYJKoZIhvcNAQEBBQAEggEAALGJaH7S
# as9vvrfmAOjECzuAqKzrNQT7eWva9D7yFDiGls7w80pAqyMwYwgBq5jiekNr20Pv
# kbVHBrhSGW5yQeINnfsinz8+YYipU+N0Uq5ABG1ijVFn4Rl1poHWS242dUNrktV6
# 4ddiqxgQx9RpnY8kwVIXRVRBiACKgfCcMk7JYIvjQanz7RAZBUZh72x6Y1u/PRHw
# A4qzr0YYEexmiVrnq0/QM/xPS51d8xOTEQgxsiIlCZngEp5se8luctv1yhhrsUiH
# g07nqgFGiV0RTN4UC0rbvqdF/qPc1ePF5IzGWkSNXOaRI7nm1Phe1/7kDP+/xs63
# +92JyfBf1dQ7nA==
# SIG # End signature block
